==> img0ch-2.1.18.zip: img0ch/_template/default/search_text_mobile.cs <==
<html>
<head>
<title>img0ch - S(޲ٔ)</title>
<meta http-equiv=Content-Type content="text/html;charset=sjis">
</head>
<body>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>

<a name=#h>
<a href=<?cs var:html_escape(BBSURI) ?>/i/></a>
<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
<a href=#f accesskey=8></a><br>

<?cs if:Disabled ?>
<p>݌@\͒~ł</p>
<?cs else ?>
<form action=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi method=post>
<input type=text name=query value="<?cs var:html_escape(Query) ?>">
<select name=type>
<option value=FROM>O</option>
<option value=mail>Ұ</option>
<option value=date></option>
<option value=id>ID</option>
<option value=MESSAGE selected>{</option>
</select>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=m value=1>
<input type=submit value=>
</form>
<?cs /if ?>

<?cs if:Query ?>
<hr>
<a name=p>
u<?cs var:html_escape(Query) ?>v̌ʁF<?cs var:html_escape(Total) ?><br>
<?cs if:Prev ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Prev) ?>&type=<?cs var:html_escape(SearchType) ?>" accesskey=4>&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(item.num) ?>&type=<?cs var:html_escape(SearchType) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Next) ?>&type=<?cs var:html_escape(SearchType) ?>" accesskey=6>&gt;&gt;</a><?cs /if ?>
<hr>
<?cs each:item = Result ?>
<?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:html_escape(item.date) ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<a href="http://example.ddo.jp/aas/a.i/
<?cs var:html_escape(AASBase) ?>/
<?cs var:html_escape(BBS) ?>/
<?cs var:html_escape(item.key) ?>/
<?cs var:html_escape(item.resno) ?>">AAS</a>
<br>
<?cs var:item.text ?>
<br>
<a href=<?cs var:CGIURI ?>/r.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/<?cs var:item.resno ?>>
<?cs var:item.subject ?></a>&nbsp;(<?cs var:item.count ?>ڽ̂<?cs var:item.found ?>Y)
<hr>
<?cs /each ?>
<a href=#p accesskey=5></a>
<?cs /if ?>
<a name=#f>
<a href=#h accesskey=2></a>
<p><a href=http://img0ch.sourceforge.jp/m/>img0ch-st.cgi - img0ch BBS</a></p>
</body>
</html>

==> img0ch-3.1.1.zip: img0ch/_template/default/search_text_mobile.cs <==
<html>
<head>
<title>img0ch - S(޲ٔ)</title>
<meta http-equiv=Content-Type content="text/html;charset=sjis">
</head>
<body>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>

<a name=#h>
<a href=<?cs var:html_escape(BBSURI) ?>/i/></a>
<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
<a href=#f accesskey=8></a><br>

<?cs if:Disabled ?>
<p>݌@\͒~ł</p>
<?cs else ?>
<form action=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi method=post>
<input type=text name=query value="<?cs var:html_escape(Query) ?>">
<select name=type>
<option value=subject<?cs if:SelectedSubject ?> selected<?cs /if ?>>گނ̑薼</option>
<option value=FROM<?cs if:SelectedFrom ?> selected<?cs /if ?>>O</option>
<option value=mail<?cs if:SelectedMail ?> selected<?cs /if ?>>Ұ</option>
<option value=date<?cs if:SelectedDate ?> selected<?cs /if ?>></option>
<option value=id<?cs if:SelectedId ?> selected<?cs /if ?>>ID</option>
<option value=MESSAGE<?cs if:SelectedMessage ?> selected<?cs /if ?>>{</option>
</select>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=m value=1>
<input type=submit value=>
</form>
<?cs /if ?>

<?cs if:Query ?>
<hr>
<a name=p>
u<?cs var:html_escape(Query) ?>v̌ʁF<?cs var:html_escape(Total) ?><br>
<?cs if:Prev ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Prev) ?>&type=<?cs var:html_escape(SearchType) ?>" accesskey=4>&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(item.num) ?>&type=<?cs var:html_escape(SearchType) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?word=<?cs var:html_escape(QueryURLEscaped) ?>&m=1&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Next) ?>&type=<?cs var:html_escape(SearchType) ?>" accesskey=6>&gt;&gt;</a><?cs /if ?>
<hr>
<?cs each:item = Result ?>
<?cs var:html_escape(item.resno) ?>:<b><?cs var:item.name ?></b><?cs var:item.date ?>
<?cs if:item.mail ?>
 [<?cs var:html_escape(item.mail) ?>]
 <?cs /if ?>
<a href="http://example.ddo.jp/aas/a.i/
<?cs var:html_escape(AASBase) ?>/
<?cs var:html_escape(BBS) ?>/
<?cs var:html_escape(item.key) ?>/
<?cs var:html_escape(item.resno) ?>">AAS</a>
<br>
<?cs var:item.text ?>
<br>
<a href=<?cs var:CGIURI ?>/r.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/<?cs var:item.resno ?>>
<?cs var:html_escape(item.subject) ?></a><?cs if:item.found ?>&nbsp;(<?cs var:item.count ?>ڽ̂<?cs var:item.found ?>Y)<?cs /if ?>
<hr>
<?cs /each ?>
<a href=#p accesskey=5></a>
<?cs /if ?>
<a name=#f>
<a href=#h accesskey=2></a>
<p><a href=http://img0ch.sourceforge.jp/m/>img0ch-st.cgi - img0ch BBS</a></p>
</body>
</html>
